@@ -3,10 +3,6 @@ from test.conftest import USE_MOCK
 import pytest
 
 import vessl
-from vessl.util.constant import (
-    SWEEP_ALGORITHM_TYPE_RANDOM,
-    SWEEP_OBJECTIVE_TYPE_MAXIMIZE,
-)
 
 
 @pytest.mark.skipif(USE_MOCK, reason="Does not run if mocking is used.")
@@ -28,7 +24,7 @@ class TestSweep:
         #     cluster_name="local",
         #     start_command="echo 'Hello world!'",
         #     kernel_resource_spec_name="v1.cpu-0.mem-1",
-        #     kernel_image_url="vessl/kernels:py36.full-cpu",
+        #     kernel_image_url=IMAGE_NAME,
         # )
         pass
 
