@@ -28,7 +28,7 @@ from vessl.organization import _get_organization_name
 from vessl.project import _get_project_name
 from vessl.util import logger
 from vessl.util.common import safe_cast
-from vessl.util.constant import MOUNT_PATH_OUTPUT, MOUNT_TYPE_OUTPUT
+from vessl.util.constant import MOUNT_PATH_OUTPUT, SOURCE_TYPE_OUTPUT
 from vessl.util.exception import (
     InvalidExperimentError,
     InvalidParamsError,
@@ -410,7 +410,7 @@ def list_experiment_output_files(
         mounts = experiment.volume_mounts.mounts
 
     for volume_mount in mounts:
-        if volume_mount.source_type == MOUNT_TYPE_OUTPUT:
+        if volume_mount.source_type == SOURCE_TYPE_OUTPUT:
             base_path = volume_mount.volume.sub_path
             try:
                 files = list_volume_files(
@@ -469,7 +469,7 @@ def download_experiment_output_files(
             )
 
         for volume_mount in experiment.volume_mounts_list[worker_number].mounts:
-            if volume_mount.source_type == MOUNT_TYPE_OUTPUT:
+            if volume_mount.source_type == SOURCE_TYPE_OUTPUT:
                 return copy_volume_file(
                     source_volume_id=volume_mount.volume.volume_id,
                     source_path="",
@@ -478,7 +478,7 @@ def download_experiment_output_files(
                 )
     else:
         for volume_mount in experiment.volume_mounts.mounts:
-            if volume_mount.source_type == MOUNT_TYPE_OUTPUT:
+            if volume_mount.source_type == SOURCE_TYPE_OUTPUT:
                 return copy_volume_file(
                     source_volume_id=volume_mount.volume.volume_id,
                     source_path="",
