@@ -72,14 +72,14 @@ SWEEP_PARAMETER_RANGE_TYPES = [
 MODEL_SOURCE_EXPERIMENT = "experiment"
 MODEL_SOURCE_LOCAL = "local"
 
-MOUNT_TYPE_CODE = "code"
-MOUNT_TYPE_ARCHIVE_FILE = "archive-file"
-MOUNT_TYPE_DATASET = "dataset"
-MOUNT_TYPE_DATASET_VERSION = "dataset-version"
-MOUNT_TYPE_MODEL_VOLUME = "model-volume"
-MOUNT_TYPE_EMPTY_DIR = "empty-dir"
-MOUNT_TYPE_OUTPUT = "output"
-MOUNT_TYPE_PROJECT = "project"
+SOURCE_TYPE_CODE = "code"
+SOURCE_TYPE_ARCHIVE_FILE = "archive-file"
+SOURCE_TYPE_DATASET = "dataset"
+SOURCE_TYPE_DATASET_VERSION = "dataset-version"
+SOURCE_TYPE_MODEL_VOLUME = "model-volume"
+SOURCE_TYPE_EMPTY_DIR = "empty-dir"
+SOURCE_TYPE_OUTPUT = "output"
+SOURCE_TYPE_PROJECT = "project"
 
 MOUNT_PATH_EMPTY_DIR = "/root/"
 MOUNT_PATH_OUTPUT = "/output/"
